@@ -1,7 +1,7 @@
 package App::DuckPAN::Cmd::Server;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Starting up the web server to test instant answers
-$App::DuckPAN::Cmd::Server::VERSION = '0.185';
+$App::DuckPAN::Cmd::Server::VERSION = '0.186';
 use Moo;
 with qw( App::DuckPAN::Cmd App::DuckPAN::Restart );
 
@@ -347,7 +347,7 @@ sub get_sub_assets {
         if (my $href = $_->attr('href')) {
             # We're looking for txxx.css and sxxx.css.
             # style.css and static.css are for development mode.
-            if ($href =~ m/^\/((?:[st]\d+|style|static|serp)\.css)/) {
+            if ($href =~ m/^\/((?:[str]\d+|style|static|serp)\.css)/) {
                 my $name = $1;
                 unshift @{$self->page_info->{css}},
                   {
@@ -436,7 +436,7 @@ App::DuckPAN::Cmd::Server - Starting up the web server to test instant answers
 
 =head1 VERSION
 
-version 0.185
+version 0.186
 
 =head1 AUTHOR
 
